%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program calculates free-convective heat transfer in an enclosure, 
% based on four different empirical correlations found in literature.

% The calculations are based on a closed vertical concentric cylinder, with
% the inner and outer cylinder walls at fixed temperatures. Top and bottom
% walls of the enclosure are adiabatic. 

% For the first two correlations, it is assumed that the cylinder is
% "unrolled" into a long rectangular box. The last two correlations are
% based on vertical concentric cylinders. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


g = 9.81; % gravity, m/s^2

% Properties water (from ANSYS material library)
k = 0.6069; % thermal conductivity, W/(m K)
mu = 8.899*(10^-4); % dynamic viscosity,
rho = 997; % density,  kg/m^3
v = mu/rho; % kinematic viscosity
cp = 4181.7; % specific heat capacity
alpha = k/(rho*cp); % thermal diffusivity
beta = 2.57*(10^-4); % thermal expansion coefficient
Pr = 6.131; % Prandtl number

% Properties concentric cylinder
Do = 0.04; % outer diameter m
Di = (2*Do)/3; % inner diameter, m
annulus = Do-Di; %
Touter = 4; % temperature outer wall, C

% Allocating space for vectors
Q1 = zeros(1,6);   % (W/m^2)
Q2 = zeros(1,6);
Q3 = zeros(1,6);
Q4 = zeros(1,6);
Q5 = zeros(1,6);

htc1 = zeros(1,6);  %(W/m^2 K)
htc2 = zeros(1,6);
htc3 = zeros(1,6);
htc4 = zeros(1,6);

Nu1 = zeros(1,6);
Nu2 = zeros(1,6);
Nu3 = zeros(1,6);
Nu4 = zeros(1,6);

% k_effective was calculated for use in further studies
k_effective1 = zeros(1,6); %(W/m K)
k_effective2 = zeros(1,6);
k_effective3 = zeros(1,6);
k_effective4 = zeros(1,6);


% Correlation 4.96 (and 4.97) from Handbook of Heat Transfer Fundamentals
% by Rohsenhow et al. 1998. Chapter 4, p. 4.52. 
% Valid for "Heat Transfer in Vertical Parallelepiped Cavities: 
% theta=90 degrees". H/L >= 5, W/L >= 5, Pr >= 4, Ra(H/L)^3< 4x10^12.

i = 1;
for Tinner = 50:10:100
    deltaT = Tinner - Touter;
    
    L = annulus;
    H = 10*Do;
    W = 2*pi*(Do/2); % Perimeter of a circle
    
    RaL = (g*beta*deltaT*(L^3))/(v*alpha);
    
    if (RaL*((H/L)^3) < 4*10^12)
        Nusselt = [1, 0.36*Pr^0.051*((L/H)^0.36)*RaL^0.25, 0.084*Pr^0.051*((L/H)^0.1)*RaL^0.3];
        Nu = max(Nusselt);
        htc = (Nu*k)/L; 
        Q1(i) = htc * deltaT; 
    else
        Nu = 0.039*(RaL^(1/3));
        htc = (Nu*k)/L;
        Q1(i) = htc * deltaT; 
    end
    
    htc1(i) = htc; 
    Nu1(i) = Nu;
    k_effective1(i) = Nu*k;
    
    i = i+1;
end

% Correlation from Convection Heat Transfer by Bejan, 2013 for Rectangular 
% Enclosures Heated from the Side.  RaH^-1/4 < H/L <RaH^1/4. 

j = 1;
for Tinner = 50:10:100
    deltaT = Tinner - Touter;
    
    L = annulus;
    H = 10*Do;
    D = 2*pi*(Do/2);
    
    RaH = (g*beta*deltaT*(H^3))/(v*alpha);
    Nu = 0.364*(L/H)*(RaH^(1/4));
    htc = (Nu*k)/L; %
    
    Q2(j) = htc * deltaT;
    htc2(j) = htc;
    Nu2(j) = Nu;
    k_effective2(j) = Nu*k;
    
    j = j+1;
end


% Correlation from "A new study of laminar natural convection in two
% concentric vertical cylinders" by A. Hadjadj et al., 1999. 

m = 1;
for Tinner = 50:10:100
    deltaT = Tinner - Touter;
    
    L = annulus;
    H = 10*Do;
    Ro = Do/2;
    A = H/Ro;
    
    Gr = (g*beta*deltaT*(L^3))/(v*v);
    RaRo= Pr*Gr;
    Nu = 0.133*(RaRo^0.33)*(A^(-0.32));
    htc = (Nu*k)/L;
    
    Q3(m) = htc * deltaT;
    htc3(m) = htc;
    Nu3(m) = Nu;
    k_effective3(m) = Nu*k;
    
    m = m+1;
end

% Correlation from VDI-Wrmeatlas 2006 for Vertical Annular Gaps

n = 1;
for Tinner = 50:10:100
    deltaT = Tinner - Touter;
    
    S = annulus;
    H = 10*Do;
    ri = Di/2;
    ra = Do/2;
    C1 = 0;
    C2 = 0;
    n1 = 0;
    n2 = 0;
    
    RaS = (g*beta*deltaT*(S^3))/(v*alpha);
    N = ((RaS*(H/S)^3)^-0.25)*(H/ri);
    
    if (N < 0.2)
        C1 = 0.48;
        C2 = 854;
        n1 = 0.75;
        n2 = 0;
    else if (N < 1.48)
            C1 = 0.93;
            C2 = 1646;
            n1 = 0.84;
            n2 = 0.36;
        else
            C1 = 0.49;
            C2 = 862;
            n1 = 0.95;
            n2 = 0.80;
        end
    end

    Numerator = C1*RaS*(H/S)^2;
    Denominator = C2*((H/ra)^4)*(ri/H)+((RaS*(H/S)^3)^n1)*(ri/H)^n2;
    Nu = Numerator/Denominator;
    htc = (Nu*k)/S;
    
    Q4(n) = htc * deltaT;
    htc4(n) = htc;
    Nu4(n) = Nu;
    k_effective4(n) = Nu*k;
    
    n = n+1;
end

